aquestalk-go

module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2026 License: MIT

README ΒΆ

πŸ—£οΈ aquestalk-go

Go Reference CI (Go) GitHub license Made in Slovakia

aquestalk-go provides unofficial Go bindings for the AquesTalk Japanese TTS engine using purego.

✨ Features

  • Pure Go bindings using purego, no cgo required
  • Dynamic library loading
  • Support for:
    • AquesTalk1
    • AquesTalk2
    • AquesTalk10

πŸš€ Getting Started

Install using this command:

go get github.com/SladkyCitron/aquestalk-go

[!NOTE] You must independently obtain the official AquesTalk dynamic libraries from AQUEST. They are not included in this repository.

πŸ“š Example

package main

import (
    "os"

    "github.com/SladkyCitron/aquestalk-go/aqtk10"
)

func main() {
    aq, err := aqtk10.New("AquesTalk.dll")
    if err != nil {
        panic(err)
    }

    wavBytes, err := aq.Synthe(aqtk10.VoiceF1, "こんにけわ。")
    if err != nil {
        panic(err)
    }

    if err := os.WriteFile("output.wav", wavBytes, 0644); err != nil {
        panic(err)
    }
}

Complete code examples can be found in the example/ directory.

πŸ“– Documentation

All documentation is available at pkg.go.dev.

βš–οΈ License

Copyright Β© 2026 SladkyCitron

Licensed under the MIT License (see LICENSE) - free to use, fork, remix, and share!

⚠️ Licensing Notice

This project only provides bindings. It does not include AquesTalk binaries. You are responsible for obtaining the appropriate licenses from AQUEST.

❀️ Acknowledgements

  • AQUEST for creating AquesTalk
  • purego for making pure Go bindings possible
  • Defoko (whose voice was originally generated using AquesTalk1) for inspiring this project πŸ’œ

Directories ΒΆ

Path Synopsis
Package aqtk1 provides Go bindings for AquesTalk1.
Package aqtk1 provides Go bindings for AquesTalk1.
Package aqtk10 provides Go bindings for AquesTalk10.
Package aqtk10 provides Go bindings for AquesTalk10.
Package aqtk2 provides Go bindings for AquesTalk2.
Package aqtk2 provides Go bindings for AquesTalk2.
example
aqtk1 command
aqtk10 command
aqtk2 command
internal
lib

Jump to